##  Add Business Capabilities
Once you’ve defined your initial set of business capabilities, import them using one of the following methods.
Import Methods for Business Capabilities Method | Description | When Recommended | Detailed Information
---|---|---|---
Reference catalog | Import industry-specific, best-practice business capabilities from the SAP LeanIX reference catalog, ensuring high data quality and improving fact sheet standardization. Review available business capabilities and import relevant ones to your workspace. | You want to import best-practice reference data for business capabilities from the reference catalog. | [Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Import business capabilities from best-practice, industry-specific business capabilities and customize them to suit your organization’s needs.")
Inventory builder |  Add data from architectural documents (images) using the inventory builder. You can import multiple fact sheet types at once by specifying their type. Inventory builder is an optional feature. You can activate it in your workspace. | You have architectural data in image format (pictures or diagrams). | [Inventory Builder](https://help.sap.com/docs/leanix/ea/inventory-builder?locale=en-US&state=PRODUCTION&version=CLOUD "The inventory builder uses AI to analyze diagrams, images, and text-based files. It extracts fact sheets and relations to help you build your inventory faster. You can review, adjust, and create fact sheets from discovered data.")
Excel import | Import data using Excel spreadsheets. You can add and update fact sheets of multiple types at once. | You want to import data using Excel spreadsheets manually. | [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.")


